@@ -5,7 +5,7 @@ import sys
 
 sys.path.append(os.path.dirname(os.path.abspath(__file__)))
 
-os.environ.setdefault("DJANGO_SETTINGS_MODULE", "test_project.settings_no_db")
+os.environ.setdefault("DJANGO_SETTINGS_MODULE", "test_project.settings")
 
 import django
 import django_compat_patcher
